@@ -3,13 +3,19 @@ from typing import Any
 import click
 from requests.exceptions import ConnectionError
 
-from ggshield.cmd.common_options import add_common_options
+import ggshield.verticals.hmsl.utils as hmsl_utils
+from ggshield.cmd.utils.common_options import add_common_options
+from ggshield.cmd.utils.context_obj import ContextObj
 from ggshield.core.client import create_client
 from ggshield.core.config import Config
 from ggshield.core.errors import AuthError, UnexpectedError
-from ggshield.core.utils import dashboard_to_api_url
+from ggshield.core.url_utils import dashboard_to_api_url
 
-from .utils import CONNECTION_ERROR_MESSAGE
+
+CONNECTION_ERROR_MESSAGE = (
+    "Could not connect to GitGuardian.\n"
+    "Please check your internet connection and if the specified URL is correct."
+)
 
 
 @click.command()
@@ -18,6 +24,7 @@ from .utils import CONNECTION_ERROR_MESSAGE
     required=False,
     type=str,
     help="URL of the instance to logout from.",
+    metavar="URL",
 )
 @click.option(
     "--revoke/--no-revoke",
@@ -25,7 +32,12 @@ from .utils import CONNECTION_ERROR_MESSAGE
     default=True,
     help="Whether the token should be revoked on logout before being removed from the configuration.",
 )
-@click.option("--all", "all_", is_flag=True, help="Iterate over every saved tokens.")
+@click.option(
+    "--all",
+    "all_",
+    is_flag=True,
+    help="Remove authentication for all instances.",
+)
 @add_common_options()
 @click.pass_context
 def logout_cmd(
@@ -39,7 +51,7 @@ def logout_cmd(
     If not specified, ggshield will logout from the default instance.
     The `--all` option can be used if you want to logout from all your GitGuardian instances.
     """
-    config = ctx.obj["config"]
+    config = ContextObj.get(ctx).config
 
     if all_:
         for _instance in config.auth_config.instances:
@@ -55,6 +67,7 @@ def logout(config: Config, instance_url: str, revoke: bool) -> None:
     check_account_config_exists(config, instance_url)
     if revoke:
         revoke_token(config, instance_url)
+        hmsl_utils.remove_token_from_disk()
     delete_account_config(config, instance_url)
 
     click.echo(
@@ -75,7 +88,6 @@ def check_account_config_exists(config: Config, instance_url: str) -> None:
 
 
 def revoke_token(config: Config, instance_url: str) -> None:
-
     instance = config.auth_config.get_instance(instance_url)
 
     assert instance.account is not None
@@ -84,7 +96,7 @@ def revoke_token(config: Config, instance_url: str) -> None:
     client = create_client(
         token,
         dashboard_to_api_url(instance_url),
-        allow_self_signed=config.allow_self_signed,
+        allow_self_signed=config.user_config.allow_self_signed,
     )
     try:
         response = client.post(endpoint="token/revoke")
