@@ -18,8 +18,8 @@ from ggshield.cmd.secret.scan.repo import repo_cmd
 from ggshield.cmd.secret.scan.secret_scan_common_options import (
     add_secret_scan_common_options,
 )
+from ggshield.cmd.utils.context_obj import ContextObj
 from ggshield.core.client import create_client_from_config
-from ggshield.core.config import Config
 from ggshield.core.text_utils import display_error
 
 
@@ -67,14 +67,15 @@ def scan_group(
 def scan_group_impl(ctx: click.Context) -> int:
     """Implementation for scan_group(). Must be a separate function so that its code can
     be reused from the deprecated `cmd.scan` package."""
-    ctx.obj["client"] = create_client_from_config(ctx.obj["config"])
+    ctx_obj = ContextObj.get(ctx)
+    ctx_obj.client = create_client_from_config(ctx_obj.config, ctx_obj.ui)
     return_code = 0
 
-    config: Config = ctx.obj["config"]
+    config = ctx_obj.config
 
     max_commits = get_max_commits_for_hook()
     if max_commits:
-        config.max_commits_for_hook = max_commits
+        config.user_config.max_commits_for_hook = max_commits
 
     return return_code
 
