@@ -3,7 +3,6 @@ import shutil
 import subprocess
 import sys
 import tempfile
-from functools import partial
 from pathlib import Path
 from typing import Any, Dict, List, Set
 
@@ -13,24 +12,23 @@ from ggshield.cmd.secret.scan.secret_scan_common_options import (
     add_secret_scan_common_options,
     create_output_handler,
 )
-from ggshield.core.config import Config
-from ggshield.core.constants import MAX_WORKERS
+from ggshield.cmd.utils.context_obj import ContextObj
 from ggshield.core.errors import UnexpectedError
-from ggshield.core.file_utils import get_files_from_paths
-from ggshield.core.text_utils import create_progress_bar
-from ggshield.scan import Files, ScanCollection, ScanContext, ScanMode, SecretScanner
+from ggshield.core.scan import ScanContext, ScanMode, Scannable
+from ggshield.core.scan.file import get_files_from_paths
+from ggshield.verticals.secret import SecretScanCollection, SecretScanner
 
 
 PYPI_DOWNLOAD_TIMEOUT = 30
 
 
-def save_package_to_tmp(temp_dir: str, package_name: str) -> None:
+def save_package_to_tmp(temp_dir: Path, package_name: str) -> None:
     command: List[str] = [
         "pip",
         "download",
         package_name,
         "--dest",
-        temp_dir,
+        str(temp_dir),
         "--no-deps",
     ]
 
@@ -53,21 +51,18 @@ def save_package_to_tmp(temp_dir: str, package_name: str) -> None:
 
 
 def get_files_from_package(
-    archive_dir: str,
+    archive_dir: Path,
     package_name: str,
     exclusion_regexes: Set[re.Pattern],
     verbose: bool,
-) -> Files:
-    archive_dir_path = Path(archive_dir)
-    archive: Path = next(archive_dir_path.iterdir())
+) -> List[Scannable]:
+    archive: Path = next(archive_dir.iterdir())
     unpack_kwargs: Dict[str, str] = (
         {"format": "zip"} if archive.suffix == ".whl" else {}
     )
 
     try:
-        shutil.unpack_archive(
-            str(archive), extract_dir=archive_dir_path, **unpack_kwargs
-        )
+        shutil.unpack_archive(str(archive), extract_dir=archive_dir, **unpack_kwargs)
     except Exception as exn:
         raise UnexpectedError(f'Failed to unpack package "{package_name}": {exn}.')
 
@@ -78,7 +73,8 @@ def get_files_from_package(
         exclusion_regexes=exclusion_regexes,
         recursive=True,
         yes=True,
-        verbose=verbose,
+        display_scanned_files=verbose,
+        display_binary_files=verbose,
         ignore_git=True,
     )
 
@@ -93,44 +89,47 @@ def pypi_cmd(
     **kwargs: Any,
 ) -> int:  # pragma: no cover
     """
-    scan a pypi package <NAME>.
+    Scan a pypi package.
+
+    Under the hood this command uses the `pip download` command to download the python
+    package.
+
+    You can use pip environment variables or configuration files to set `pip download`
+    parameters as explained in [pip documentation][1].  For example, you can set pip
+    `--index-url` parameter with the `PIP_INDEX_URL` environment variable.
+
+    [1]: https://pip.pypa.io/en/stable/topics/configuration/
     """
-    config: Config = ctx.obj["config"]
+    ctx_obj = ContextObj.get(ctx)
+    config = ctx_obj.config
     output_handler = create_output_handler(ctx)
+    verbose = config.user_config.verbose
 
     with tempfile.TemporaryDirectory(suffix="ggshield") as temp_dir:
-        save_package_to_tmp(temp_dir=temp_dir, package_name=package_name)
+        temp_path = Path(temp_dir)
+        save_package_to_tmp(temp_dir=temp_path, package_name=package_name)
 
-        files: Files = get_files_from_package(
-            archive_dir=temp_dir,
+        files = get_files_from_package(
+            archive_dir=temp_path,
             package_name=package_name,
-            exclusion_regexes=ctx.obj["exclusion_regexes"],
-            verbose=config.verbose,
+            exclusion_regexes=ctx_obj.exclusion_regexes,
+            verbose=config.user_config.verbose,
         )
 
-        with create_progress_bar(doc_type="files") as progress:
-
+        with ctx_obj.ui.create_scanner_ui(len(files), verbose=verbose) as ui:
             scan_context = ScanContext(
                 scan_mode=ScanMode.PYPI,
                 command_path=ctx.command_path,
             )
 
             scanner = SecretScanner(
-                client=ctx.obj["client"],
-                cache=ctx.obj["cache"],
-                ignored_matches=config.secret.ignored_matches,
+                client=ctx_obj.client,
+                cache=ctx_obj.cache,
+                ignored_matches=config.user_config.secret.ignored_matches,
                 scan_context=scan_context,
-                ignored_detectors=config.secret.ignored_detectors,
-                ignore_known_secrets=config.ignore_known_secrets,
+                ignored_detectors=config.user_config.secret.ignored_detectors,
             )
-            task_scan = progress.add_task(
-                "[green]Scanning PyPI Package...", total=len(files.files)
-            )
-            results = scanner.scan(
-                files.files,
-                progress_callback=partial(progress.update, task_scan),
-                scan_threads=MAX_WORKERS,
-            )
-        scan = ScanCollection(id=package_name, type="path_scan", results=results)
+            results = scanner.scan(files, scanner_ui=ui)
+        scan = SecretScanCollection(id=package_name, type="path_scan", results=results)
 
         return output_handler.process_scan(scan)
