@@ -1,12 +1,17 @@
-import os
 from dataclasses import fields, is_dataclass
 from pathlib import Path
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union
+from typing import Any, Dict, List, Literal, Optional, Union, overload
 
 import yaml
+import yaml.parser
+import yaml.scanner
 
-from ggshield.core.constants import AUTH_CONFIG_FILENAME
-from ggshield.core.dirs import get_config_dir
+from ggshield.core.constants import (
+    AUTH_CONFIG_FILENAME,
+    DEFAULT_CONFIG_FILENAME,
+    USER_CONFIG_FILENAMES,
+)
+from ggshield.core.dirs import get_config_dir, get_user_home_dir
 from ggshield.core.errors import UnexpectedError
 
 
@@ -23,11 +28,12 @@ def replace_in_keys(data: Union[List, Dict], old_char: str, new_char: str) -> No
             replace_in_keys(element, old_char=old_char, new_char=new_char)
 
 
-def load_yaml_dict(path: str) -> Optional[Dict[str, Any]]:
-    if not os.path.isfile(path):
+def load_yaml_dict(path: Union[str, Path]) -> Optional[Dict[str, Any]]:
+    path = Path(path)
+    if not path.exists():
         return None
 
-    with open(path) as f:
+    with path.open() as f:
         try:
             data = yaml.safe_load(f) or {}
         except (yaml.parser.ParserError, yaml.scanner.ScannerError) as e:
@@ -40,7 +46,7 @@ def load_yaml_dict(path: str) -> Optional[Dict[str, Any]]:
     return data
 
 
-def save_yaml_dict(data: Dict[str, Any], path: str) -> None:
+def save_yaml_dict(data: Dict[str, Any], path: Union[str, Path]) -> None:
     p = Path(path)
     p.parent.mkdir(parents=True, exist_ok=True)
     with p.open("w") as f:
@@ -48,17 +54,50 @@ def save_yaml_dict(data: Dict[str, Any], path: str) -> None:
             stream = yaml.dump(data, indent=2, default_flow_style=False)
             f.write(stream)
         except Exception as e:
-            raise UnexpectedError(
-                f"Error while saving config in {path}:\n{str(e)}"
-            ) from e
+            raise UnexpectedError(f"Failed to save config to {path}:\n{str(e)}") from e
 
 
-def get_auth_config_filepath() -> str:
-    return os.path.join(get_config_dir(), AUTH_CONFIG_FILENAME)
+def get_auth_config_filepath() -> Path:
+    return get_config_dir() / AUTH_CONFIG_FILENAME
 
 
-def get_global_path(filename: str) -> str:
-    return os.path.join(os.path.expanduser("~"), filename)
+def get_global_path(filename: str) -> Path:
+    return get_user_home_dir() / filename
+
+
+@overload
+def find_global_config_path(*, to_write: Literal[False] = False) -> Optional[Path]:
+    ...
+
+
+@overload
+def find_global_config_path(*, to_write: Literal[True]) -> Path:
+    ...
+
+
+def find_global_config_path(*, to_write: bool = False) -> Optional[Path]:
+    """
+    Returns the path to the user global config file (the file in the user home
+    directory).
+    If there is no such file:
+    - If `to_write` is False, returns None.
+    - If `to_write` is True, returns the path to the default file.
+
+    This means the function never returns None if `to_write` is True.
+    """
+    for filename in USER_CONFIG_FILENAMES:
+        path = get_global_path(filename)
+        if path.exists():
+            return path
+    return get_global_path(DEFAULT_CONFIG_FILENAME) if to_write else None
+
+
+def find_local_config_path() -> Optional[Path]:
+    for filename in USER_CONFIG_FILENAMES:
+        path = Path(filename)
+        if path.exists():
+            return path
+    return None
 
 
 def update_from_other_instance(dst: Any, src: Any) -> None:
@@ -82,24 +121,6 @@ def update_from_other_instance(dst: Any, src: Any) -> None:
             dst.__dict__[name] = value
 
 
-def ensure_path_exists(dir_path: str) -> None:
-    Path(dir_path).mkdir(parents=True, exist_ok=True)
-
-
-def get_attr_mapping(classes: Iterable[Tuple[Type[Any], str]]) -> Dict[str, str]:
-    """
-    Return a mapping from a field name to the correct class
-    raise an AssertionError if there is a field name collision
-    """
-    mapping = {}
-    for klass, attr_name in classes:
-        assert is_dataclass(klass)
-        for field_ in fields(klass):
-            assert field_.name not in mapping, f"Conflict with field '{field_.name}'"
-            mapping[field_.name] = attr_name
-    return mapping
-
-
 def remove_common_dict_items(dct: Dict, reference_dct: Dict) -> Dict:
     """
     Returns a copy of `dct` with all items already in `reference_dct` removed.
